@@ -1,5 +1,5 @@
 growth.intervals <-
-function (x, y, zero.slope = 0.01) 
+function (x, y, zeroSlope = 0.01) 
 {
     l <- paste("0", paste(as.integer(diff(y) > 0), collapse = ""), 
         "0", sep = "")
@@ -9,8 +9,8 @@ function (x, y, zero.slope = 0.01)
     index.growth.to <- gregexpr("10", l)[[1]]
     slope <- (180/pi) * atan((y[index.growth.to] - y[index.growth.from])/(x[index.growth.to] - 
         x[index.growth.from]))
-    l <- slope > zero.slope
-    if (any(l)) 
+    l <- slope > zeroSlope
+    if (any(l))	    
         return(cbind(index.growth.from[l], index.growth.to[l]))
     else return()
 }
